
.. py:currentmodule:: pythreejs

TorusKnotBufferGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: TorusKnotBufferGeometry(radius=1, tube=0.4, tubularSegments=64, radialSegments=8, p=2, q=3, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BaseBufferGeometry`.

    Three.js docs: https://threejs.org/docs/#api/geometries/TorusKnotGeometry


    .. py:attribute:: radius

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: tube

        .. sourcecode:: python

            CFloat(0.4, allow_none=False).tag(sync=True)

    .. py:attribute:: tubularSegments

        .. sourcecode:: python

            CInt(64, allow_none=False).tag(sync=True)

    .. py:attribute:: radialSegments

        .. sourcecode:: python

            CInt(8, allow_none=False).tag(sync=True)

    .. py:attribute:: p

        .. sourcecode:: python

            CInt(2, allow_none=False).tag(sync=True)

    .. py:attribute:: q

        .. sourcecode:: python

            CInt(3, allow_none=False).tag(sync=True)

